@@ -196,7 +196,7 @@ def startEngine():
     #Start Event Loop Processing
     eventLoop.fastConnect(nsmServerControl.process)
     eventLoop.fastConnect(jackClient._setPlaybackSeconds)
-    eventLoop.slowConnect(nsmServerControl.processSingleInstance)
+    eventLoop.slowConnect(nsmServerControl.listenToAnotherInstanceAttempt)
 
     #Send initial data
     #The decision if we are already in a session on startup or in "choose a session mode" is handled by callbacks
@@ -257,30 +257,23 @@ def systemProgramsSetBlacklist(executableNames:tuple):
     programDatabase.userBlacklist = tuple(executableNames)
     #Needs rebuild through the GUI. We have no callback for this.
 
-def getCache()->dict:
-    """Returns the cached database from buildProgramDatabase. No automatic update. Empty on program
-    start
-
-    db = {
-        "programs" : list of dicts
-        iconPaths : list of strings
-    }
-    """
-    return programDatabase.getCache()
-
-def setCache(cache:dict):
-    programDatabase.setCache(cache)
-
+def getNsmClients()->list:
+    """Returns a, probably cached, list of dicts that represent all nsm capable clients
+    on this system. Including the list of clients the user added themselves"""
+    return programDatabase.getNsmClients()
 
 def getNsmExecutables()->set:
-    """Cached access fort fast membership tests. Is this program in the PATH?"""
+    """Cached access fort fast membership tests. Is this program in the PATH?
+    This is just to check if an executable is available on this system.
+
+    The content of the set are executable names, the same as ["agordejoExec"] from getNsmClients elements
+    """
     return programDatabase.nsmExecutables
 
 def getUnfilteredExecutables()->list:
     """Return a list of unique names without paths or directories of all exectuables in users $PATH.
     This is intended for a program starter prompt. GUI needs to supply tab completition or search
     itself"""
-    programDatabase.unfilteredExecutables = programDatabase.buildCache_unfilteredExecutables() #quick call
     return programDatabase.unfilteredExecutables
 
 
@@ -330,10 +323,6 @@ def sessionQuery(nsmSessionName:str):
     Exports a single session project in the format of nsmServerControl.exportSessionsAsDicts"""
     return nsmServerControl.sessionAsDict(nsmSessionName)
 
-def sessionForceLiftLock(nsmSessionName:str):
-    nsmServerControl.forceLiftLock(nsmSessionName)
-    callbacks._sessionLocked(nsmSessionName, False)
-
 def sessionDelete(nsmSessionName:str):
     nsmServerControl.deleteSession(nsmSessionName)
 
