@@ -41,6 +41,8 @@ from uuid import uuid4
 from datetime import datetime
 from sys import exit as sysexit
 from time import sleep
+from ctypes import c_ulong
+from functools import lru_cache
 
 #Our files
 from .comparedirectories import md5_dir
@@ -316,7 +318,7 @@ class NsmServerControl(object):
         #Deactivate hooks for now. During init no hooks may be called,
         #but some functions want to do that already. We setup the true hooks at the end of init
         self.sessionOpenReadyHook= self.sessionOpenLoadingHook= self.sessionClosedHook= self.clientStatusHook= self.singleInstanceActivateWindowHook= self.dataClientNamesHook= self.dataClientDescriptionHook= nothing
-
+        self.sessions_lockfile_directory = getenv("XDG_RUNTIME_DIR")
         self._queue = list() #Incoming OSC messages are buffered here.
 
         #Status variables that are set by our callbacks
@@ -369,17 +371,24 @@ class NsmServerControl(object):
         #self.nsmOSCUrl must be a tuple compatible to the result of urlparse. (hostname, port)
         self.singleInstanceSocket = None
         if parameterNsmOSCUrl:
+            #There is either a user provided nsm url via --url commandline or paramter the GUI detected a running nsmd and let the use choose that.
             o = urlparse(parameterNsmOSCUrl)
             #self.nsmOSCUrl = (o.hostname, o.port)  #this forces lowercase. in rare circumstances this is not correct and we must be case sensitive. fix:
             self.nsmOSCUrl = o.netloc.split(":")[0], o.port
         else:
             envResult = self._getNsmOSCUrlFromEnvironment()
             if envResult:
+                #In case there is no actual nsmd running but there still was a NSM_URL env var, e.g. over the network, use this.
+                #There is a corner case that the env is local but the user chose to ignore the GUI way (nsmd 1.6.0) to proivde us directly with a specific URL.
                 self.nsmOSCUrl = envResult
             else:
                 #This is the default case. User just starts the GUI. The other modes are concious decisions to either start with URL as parameter or in an NSM environment.
-                #But now we need to test if the user accidentaly opened a second GUI, which would start a second server.
+                #We need to test if the user accidentaly opened a second GUI, which would start a second server.
                 self._setupAndTestForSingleInstance() #This might quit the whole program and we will never see the next line.
+                #TODO: there is a corner case: 1) manually start nsmd locally   2) start agordejo first time and connect to running nsmd  3) start 2nd agordejo and connect to the same server.
+                #it will not prevent it. But we need it because all other scenarios prevent agordejo multiple times for actual different servers, which is of course wanted.
+                #Better let something uncorrect slip than to prevent legit usecases!
+                #The important check here is to see if Agordejo, with internal nsmd, was started twice or not. Which works. That's all.
                 self.nsmOSCUrl = self._generateFreeNsmOSCUrl()
 
         assert self.nsmOSCUrl
@@ -417,7 +426,7 @@ class NsmServerControl(object):
         self.dataClientNamesHook = dataClientNamesHook
         self.dataClientDescriptionHook = dataClientDescriptionHook
         self.dataClientTimelineMaximumDurationChangedHook = dataClientTimelineMaximumDurationChangedHook
-        self.singleInstanceActivateWindowHook = singleInstanceActivateWindowHook #added to self.processSingleInstance() to listen for a message from another wannabe-instance
+        self.singleInstanceActivateWindowHook = singleInstanceActivateWindowHook #added to self.listenToAnotherInstanceAttempt() to listen for a message from another wannabe-instance
 
         self._receiverActive = True
         logger.info("nsmservercontrol init is complete. Ready for event loop")
@@ -425,22 +434,28 @@ class NsmServerControl(object):
 
     #Internal Methods
     def _setupAndTestForSingleInstance(self):
-        """on program startup trigger this if there is already another instance of us running.
-        This socket is only
+        """
+        On program startup trigger this if there is already another instance of us running.
+        This is before anything NSM was done.
         """
         self.singleInstanceSocket = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
         logger.info("Testing if another non-specific Agordejo is running.")
         try:
-            ## Create an abstract socket, by prefixing it with null.
+            # This is for the first agordejo instance, when no other is running. We set up
+            # a socket and listen throughout the runtime of our instance.
+            #
+            # Create an abstract socket, by prefixing it with null.
             # this relies on a feature only in linux, when current process quits, the
             # socket will be deleted.
             self.singleInstanceSocket.bind('\0' + "agordejo")
             self.singleInstanceSocket.listen(1)
             self.singleInstanceSocket.setblocking(False)
             logger.info("No other non-specific  Agordejo found. Starting GUI")
-            #Continue in self.processSingleInstance()
+            #Continue in self.listenToAnotherInstanceAttempt()
             return True
         except socket.error:
+            # This is for the 2nd agordejo instance that has detected there is already another
+            # instance running.  We will exit here before anything related to NSM has happened.
             logger.error("GUI for this nsmd server already running. Informing the existing application to show itself.")
             self.singleInstanceSocket.connect('\0' + "agordejo")
             self.singleInstanceSocket.send("agordejoactivate".encode());
@@ -449,10 +464,17 @@ class NsmServerControl(object):
             #print ("not executed")
             return False
 
-    def processSingleInstance(self):
-        """Tests our unix socket for an incoming signal.
+    def listenToAnotherInstanceAttempt(self):
+        """
+        This is for the agordejo instance that keeps running. We inform the GUI via hook
+        to show info to the user that a 2nd instance wanted to start.
+
+        Tests our unix socket for an incoming signal.
         if received forward to the engine->gui
-        Can be added to a slower event loop, so it is not in self.process"""
+
+        Must be added to an event loop, so will only start once the program has started.
+        Can be added to a slower event loop, so it is not in self.process
+        """
         if self.singleInstanceSocket:
             try:
                 connection, client_address = self.singleInstanceSocket.accept() #This blocks and waits for a message
@@ -466,7 +488,26 @@ class NsmServerControl(object):
 
     def _setPause(self, state:bool):
         """Set both the socket and the thread into waiting mode or not.
-        With this we can wait for answers until we resume async operation"""
+        With this we can wait for answers until we resume async operation
+
+        This is a potential freeze/lock operation if we make a request to an
+        external nsmd, which already closed.
+        We will check if the socket is still open before going into blocking mode.
+        """
+        if not self.ourOwnServer and not self._isNsmdRunning(self.nsmOSCUrl): #see docstring
+            #Try to clean up
+            try:
+                self.sock.shutdown(2)
+            except:
+                pass
+            try:
+                self.sock.close()
+            except:
+                pass
+            #This is a reason to let the program exit.
+            logger.error("Wanted to do a blocking call but external nsmd found not running anymore. It probably closed or crashed. Will close our GUI now. There is no risk of data loss because we were just an attached GUI anyway.")
+            sysexit() #return None switch to return None to let it crash and see the python traceback
+
         if state:
             self.sock.setblocking(True) #explicitly wait.
             self.sock.settimeout(0.5)
@@ -522,8 +563,10 @@ class NsmServerControl(object):
                     if msg:
                         self._queue.append(msg)
                 except BlockingIOError: #happens while no data is received. Has nothing to do with blocking or not.
+                    #If we lose connection to nsmd (because it was killed remotely) this will stop as well.
                     break
                 except socket.timeout:
+                    #Try again next time.
                     break
 
             for msg in self._queue:
@@ -599,7 +642,6 @@ class NsmServerControl(object):
         Returns list of arguments, can be empty.
         """
         assert not self._queue, [(m.oscpath, m.params) for m in self._queue]
-
         logger.info(f"[wait for answer]: Sending {path}: {arguments}")
         self._setPause(True)
         out_msg = _OutgoingMessage(path)
@@ -1413,27 +1455,42 @@ class NsmServerControl(object):
                 return True
         return False
 
+
+    def _simple_hash(self, s:str) -> int:
+        """This is a translation from the nsm/file.c function of the same name.
+        We use it to find the lock file on our system.
+
+        It is a djb2 hash modulo 65521
+        """
+        hashAddress = 5381
+        for i, char in enumerate(s):
+            hashAddress = ((hashAddress << 5) + hashAddress ) + ord(char)
+
+        hashAddress = c_ulong(hashAddress).value #wrap around for whatever number of bits unsinged long is on this system. 2**64 most likely
+        return hashAddress % 65521
+
+
+    @lru_cache(maxsize=128)
+    def _get_lock_file_name(self, session_name:str, full_absolute_session_path:str) -> pathlib.Path:
+        """This is a translation from the nsm/nsmd.c function of the same name.
+        We use it to find the lock file on our system.
+
+        To avoid collisions of two simple session names under either different subdirs or even
+        different session roots."""
+        #session_name in Agordejo includes subdirs. We want only the basename, like in nsmd. Luckily they are paths.
+        session_name = pathlib.Path(session_name).name #basename
+        session_hash:int = self._simple_hash(full_absolute_session_path)
+        session_lock = pathlib.Path(self.sessions_lockfile_directory, "nsm", session_name + str(session_hash))
+        return session_lock
+
+
     def _checkIfLocked(self, nsmSessionName:str)->bool:
-        basePath = pathlib.Path(self.sessionRoot, nsmSessionName)
-        assert basePath.exists()
-        lockFile = pathlib.Path(basePath, ".lock")
+        #basePath = pathlib.Path(self.sessionRoot, nsmSessionName)
+        #assert basePath.exists()
+        #lockFile = pathlib.Path(basePath, ".lock")
+        lockFile = self._get_lock_file_name(nsmSessionName, str(pathlib.Path(self.sessionRoot, nsmSessionName)))
         return lockFile.exists()
 
-    def forceLiftLock(self, nsmSessionName:str):
-        """Removes lockfile, no matter if session is actually open or just a remainder
-        from a crash.
-        If no lock exist it does nothing."""
-        self._updateSessionListBlocking()
-
-        if self._checkIfLocked(nsmSessionName):
-            basePath = pathlib.Path(self.sessionRoot, nsmSessionName)
-            assert basePath.exists() #implied by _checkIfLocked
-            lockFile = pathlib.Path(basePath, ".lock")
-            lockFile.unlink(missing_ok=True)
-            logger.info(f"{nsmSessionName} was forced to unlock by us.")
-        else:
-            logger.info(f"Tried to unlock, but {nsmSessionName} is not locked")
-
     def getSessionFiles(self, nsmSessionName:str)->list:
         """Return all session files, useful to present to the user, e.g. as warning
         before deletion"""
@@ -1566,7 +1623,6 @@ class NsmServerControl(object):
             else:
                 mycopy()
 
-            self.forceLiftLock(newName)
         except Exception as e: #we don't want to crash if user tries to copy to /root or so.
             logger.error(e)
             return False
