@@ -22,7 +22,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import logging; logger = logging.getLogger(__name__); logger.info("import")
 
 #Standard Library
-from sys import argv as sysargv
 from sys import exit as sysexit
 
 #Third Party
@@ -50,7 +49,8 @@ from .waitdialog import WaitDialog
 from .resources import *
 from .settings import SettingsDialog
 from .jacktransport import JackTransportControls
-
+from .movesessionroot import xdgVersionChange
+from .startchooserunningnsmd import checkForRunningNsmd
 
 api.eventLoop = EventLoop()
 
@@ -164,30 +164,19 @@ class MainWindow(QtWidgets.QMainWindow):
         self.ui.stack_loaded_session.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
         self.ui.stack_loaded_session.customContextMenuRequested.connect(self.customContextMenu)
 
+        #nsmd 1.6.0
+        xdgVersionChange(self.qtApp) #may present a blocking dialog, may do nothing.
+        #If another Agordejo is running, and no --nsm-url was set, we will never reach this point.
+        checkForRunningNsmd(self.qtApp, PATHS) #may present a blocking dialog, may do nothing. Injects nsm url into PATHS
 
         #Api Callbacks
         api.callbacks.sessionClosed.append(self.reactCallback_sessionClosed)
         api.callbacks.sessionOpenReady.append(self.reactCallback_sessionOpen)
         api.callbacks.singleInstanceActivateWindow.append(self.activateAndRaise)
 
-
-        #Handle the application data cache.
-        #This must happen before engineStart. If a session is already running a set of initial
-        #client-callbacks will arrive immediately, even before the eventLoop starts.
-        #If not present instruct the engine to build one.
-        #This is also needed by the prompt in sessionController and the icons
-        logger.info("Trying to restore cached program database")
-        settings = QtCore.QSettings("LaborejoSoftwareSuite", METADATA["shortName"])
-        if settings.contains("engineCache"):
-            engineCache = settings.value("engineCache", type=dict)
-            api.setCache(engineCache)
-            logger.info("Restored program database from qt cache to engine")
-            self._updateGUIWithCachedPrograms()
-        else: #First or fresh start
-            #A single shot timer with 0 durations is executed only after the app starts, thus the main window is ready.
-            logger.info("First run. Instructing engine to build program database")
-            QtCore.QTimer.singleShot(0, self.updateProgramDatabase) #includes self._updateGUIWithCachedPrograms()
-
+        #Use our wait-dialog to build the program database.
+        logger.info("Instructing engine to build program database")
+        QtCore.QTimer.singleShot(0, self.updateProgramDatabase) #includes self._updateGUIWithCachedPrograms()
 
         #Starting the engine sends initial GUI data. Every window and widget must be ready to receive callbacks here
         api.eventLoop.start()
@@ -210,7 +199,6 @@ class MainWindow(QtWidgets.QMainWindow):
                 logger.info(f"Got continue session as command line parameter but there is no session available.")
 
 
-
         if not self.isVisible():
             text = QtCore.QCoreApplication.translate("mainWindow", "Agordejo ready")
             self.systemTray.showMessage("Agordejo", text, QtWidgets.QSystemTrayIcon.Information, 2000) #title, message, icon, timeout.  #has messageClicked() signal.
@@ -259,12 +247,8 @@ class MainWindow(QtWidgets.QMainWindow):
     def _updateIcons(self):
         logger.info("Creating icon database")
 
-        engineCache = api.getCache()
-        assert engineCache
-        programs = engineCache["programs"]
-
         self.programIcons.clear()
-        for entry in programs:
+        for entry in api.getNsmClients():
             exe = entry["agordejoExec"]
 
             icon = None
@@ -293,13 +277,12 @@ class MainWindow(QtWidgets.QMainWindow):
         text = QtCore.QCoreApplication.translate("mainWindow", "Updating Program Database.\nThank you for your patience.\nIf progress freezes please kill and restart the whole program.")
 
         settings = QtCore.QSettings("LaborejoSoftwareSuite", METADATA["shortName"])
-        settings.remove("engineCache")
+        if settings.contains("engineCache"): #remove haywire data from previous releases
+            settings.remove("engineCache")
 
         logger.info("Asking api to generate program and icon database while waiting")
         diag = WaitDialog(self, text,  api.buildSystemPrograms) #save in local var to keep alive
 
-        assert api.getCache()
-        settings.setValue("engineCache", api.getCache()) # dict
         self._updateGUIWithCachedPrograms()
 
     def reactCallback_sessionClosed(self):
@@ -309,6 +292,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self.setWindowTitle(nsmSessionExportDict["nsmSessionName"])
         self.recentlyOpenedSessions.add(nsmSessionExportDict["nsmSessionName"])
 
+
     def toggleVisible(self, force:bool=None):
         if force is None:
             newState = not self.isVisible()
@@ -401,8 +385,7 @@ class MainWindow(QtWidgets.QMainWindow):
             result = True
 
         if result:
-            self.storeWindowSettings()
-            self._callSysExit()
+            self._callSysExit() #contains self.storeWindowSettings
 
     def closeEvent(self, event):
         """Window manager close.
@@ -500,7 +483,7 @@ class SessionController(object):
         self._connectMenu()
 
         #Callbacks
-        #api.callbacks.sessionOpenReady.append(lambda nsmSessionExportDict: self._switch("open")) #When loading ist done. This takes a while when non-nsm clients are in the session
+        api.callbacks.sessionOpenReady.append(lambda nsmSessionExportDict: self._switch("open")) #When loading ist done. This takes a while when non-nsm clients are in the session
         api.callbacks.sessionClosed.append(lambda: self._setMenuEnabled(None))
         api.callbacks.sessionClosed.append(lambda: self._switch("choose")) #The rest is handled by the widget itself. It keeps itself updated, no matter if visible or not.
         api.callbacks.sessionOpenReady.append(lambda nsmSessionExportDict: self._setMenuEnabled(nsmSessionExportDict))
