@@ -25,10 +25,11 @@ import logging; logger = logging.getLogger(__name__); logger.info("import")
 
 #Third Party
 from PyQt5 import QtCore, QtGui, QtWidgets
+import xdg.IconTheme #pyxdg  https://www.freedesktop.org/wiki/Software/pyxdg/
+
 
 #Engine
 import engine.api as api
-import engine.findicons as findicons
 
 #Qt
 from .descriptiontextwidget import DescriptionController
@@ -114,7 +115,10 @@ class ClientItem(QtWidgets.QTreeWidgetItem):
     def updateIcon(self, clientDict:dict):
         """Just called during init"""
         programIcons = self.parentController.mainWindow.programIcons
-        assert programIcons
+        if not programIcons:
+            return #later again.
+
+
         assert "executable" in clientDict, clientDict
         iconColumn = self.parentController.clientsTreeWidgetColumns.index("reportedName")
         if clientDict["executable"] in programIcons:
@@ -122,16 +126,16 @@ class ClientItem(QtWidgets.QTreeWidgetItem):
             assert icon, icon
             self.setIcon(iconColumn, icon) #reported name is correct here. this is just the column.
         else: #Not NSM client added by the prompt widget
-            result = findicons.findIconPath(clientDict["executable"])
+            result = xdg.IconTheme.getIconPath(clientDict["executable"]) #First attempt: let's hope the icon name has something to do with the executable name
             if result:
-                icon = QtGui.QIcon.fromTheme(str(result[0]))
+                icon = QtGui.QIcon.fromTheme(result)
             else:
                 icon = QtGui.QIcon.fromTheme(clientDict["executable"])
 
             if not icon.isNull():
                 self.setIcon(iconColumn, icon)
             else:
-                self.setIcon(iconColumn, iconFromString(clientDict["executable"]))
+                self.setIcon(iconColumn, iconFromString(clientDict["executable"])) #draw our own.
 
 class ClientTable(object):
     """Controls the QTreeWidget that holds loaded clients"""
@@ -190,6 +194,12 @@ class ClientTable(object):
         for index in range(self.clientsTreeWidget.columnCount()):
             self.clientsTreeWidget.resizeColumnToContents(index)
 
+        #And a bit more extra space
+        for index in range(self.clientsTreeWidget.columnCount()):
+            self.clientsTreeWidget.setColumnWidth(index, self.clientsTreeWidget.columnWidth(index)+25)
+
+
+
     def _cleanClients(self,  nsmSessionExportDict:dict):
         """Reset everything to the initial, empty state.
         We do not reset in in openReady because that signifies that the session is ready.
@@ -389,25 +399,6 @@ class ClientTable(object):
 class LauncherProgram(QtWidgets.QTreeWidgetItem):
     """
     An item on the left side of the window. Used to start programs and show info, but nothing more.
-
-    Example:
-     { 'categories': 'AudioVideo;Audio;X-Recorders;X-Multitrack;X-Jack;',
-       'comment': 'Easy to use pattern sequencer for JACK and NSM',
-       'comment[de]': 'Einfach zu bedienender Pattern-Sequencer',
-       'exec': 'patroneo',
-       'genericname': 'Sequencer',
-       'icon': 'patroneo',
-       'name': 'Patroneo',
-       'startupnotify': 'false',
-       'terminal': 'false',
-       'type': 'Application',
-       'version': '1.0', #desktop spec version, not progra,
-       'x-nsm-capable': 'true'}
-
-    Also:
-        'agordejoExec' : the actual nsm exe
-        'agordejoIconPath' : a priority path the engine found for us
-
     """
 
     allItems = {} # clientId : ClientItem
@@ -418,8 +409,6 @@ class LauncherProgram(QtWidgets.QTreeWidgetItem):
         self.launcherDict = launcherDict
         self.executable = launcherDict["agordejoExec"]
 
-
-
         parameterList = [] #later in update
         super().__init__(parameterList, type=1000) #type 0 is default qt type. 1000 is subclassed user type)
         self.updateData(launcherDict)
@@ -436,10 +425,11 @@ class LauncherProgram(QtWidgets.QTreeWidgetItem):
             self.setText(index, t)
 
         programIcons = self.parentController.mainWindow.programIcons
-        assert programIcons
+        if not programIcons:
+            return #later again
         if launcherDict["agordejoExec"] in programIcons:
             icon = programIcons[launcherDict["agordejoExec"]]
-            self.setIcon(self.parentController.columns.index("name"), icon) #name is correct here. this is just the column.
+            self.setIcon(self.parentController.columns.index("agordejoName"), icon) #name is correct here. this is just the column.
 
 class LauncherTable(object):
     """Controls the QTreeWidget that holds programs in the PATH.
@@ -453,7 +443,7 @@ class LauncherTable(object):
         self.launcherWidget = self.mainWindow.ui.loadedSessionsLauncher
         self.launcherWidget.setIconSize(iconSize)
 
-        self.columns = ("name", "comment", "agordejoFullPath") #basically an enum
+        self.columns = ("agordejoName", "agordejoDescription", "agordejoFullPath") #basically an enum
         self.headerLables = [
             QtCore.QCoreApplication.translate("Launcher", "Name"),
             QtCore.QCoreApplication.translate("Launcher", "Description"),
@@ -478,27 +468,23 @@ class LauncherTable(object):
         for index in range(self.launcherWidget.columnCount()):
             self.launcherWidget.resizeColumnToContents(index)
 
+        #And a bit more extra space
+        for index in range(self.launcherWidget.columnCount()):
+            self.launcherWidget.setColumnWidth(index, self.launcherWidget.columnWidth(index)+25)
+
     def _reactSignal_launcherItemDoubleClicked(self, item):
         api.clientAdd(item.executable)
 
     def buildPrograms(self):
         """Called by mainWindow.updateProgramDatabase
-
         Receive entries from the engine.
-        Entry is a dict modelled after a .desktop file.
-        But not all entries have all data. Some are barebones executable name and path.
-
-        Only guaranteed keys are agordejoExec and agordejoFullPath, which in turn are files
-        guaranteed to exist in the path.
         """
         self.launcherWidget.clear()
-        engineCache = api.getCache()
-        programs = engineCache["programs"]
+        programs = api.getNsmClients()
 
         for entry in programs:
             item = LauncherProgram(parentController=self, launcherDict=entry)
             self.launcherWidget.addTopLevelItem(item)
-
         self._adjustColumnSize()
 
 class OpenSessionController(object):
