@@ -4,32 +4,32 @@
 <context>
     <name>AskBeforeQuit</name>
     <message>
-        <location filename="../../mainwindow.py" line="331"/>
+        <location filename="../../mainwindow.py" line="329"/>
         <source>About to quit but session {} still open</source>
         <translation>Programm soll beendet werden, aber Session {} ist noch offen</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="332"/>
+        <location filename="../../mainwindow.py" line="330"/>
         <source>Do you want to save?</source>
         <translation>Möchten Sie speichern?</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="333"/>
+        <location filename="../../mainwindow.py" line="331"/>
         <source>About to quit</source>
         <translation>Programm soll beendet werden</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="342"/>
+        <location filename="../../mainwindow.py" line="340"/>
         <source>Don&apos;t Quit</source>
         <translation>Nicht Beenden</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="343"/>
+        <location filename="../../mainwindow.py" line="341"/>
         <source>Save</source>
         <translation>Speichern</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="344"/>
+        <location filename="../../mainwindow.py" line="342"/>
         <source>Discard Changes</source>
         <translation>Änderungen Verwerfen</translation>
     </message>
@@ -59,7 +59,7 @@
     <message>
         <location filename="../../designer/settings.py" line="80"/>
         <source>For advanced users only! Add executable paths to the environment, just for Agordejo and NSM. Changes need a program restart afterwards. If you want your programs in the application launcher use the launcher tab.</source>
-        <translation>Nur für fortgeschrittene Benutzer! Hier absolute Pfade hinzufügen, in denen sich ausführbare Dateien befinden. Diese Einstellungen gelten nur für Agordejo/NSM. Änderungen benötigen einen kompletten Programmneustart. Um Programme zum Schnellstarter hinzuzufügen bitte den Tab &quot;Programmstarter&quot; benutzen.</translation>
+        <translation>Nur für fortgeschrittene Benutzer! Hier absolute Pfade hinzufügen, in denen sich ausführbare Dateien befinden. Diese Einstellungen gelten nur für Agordejo/NSM. Änderungen benötigen einen kompletten Programmneustart. Um Programme zum Schnellstarter hinzuzufügen bitte den Tab &amp;quot;Programmstarter&amp;quot; benutzen.</translation>
     </message>
     <message>
         <location filename="../../designer/settings.py" line="81"/>
@@ -75,17 +75,17 @@
 <context>
     <name>Launcher</name>
     <message>
-        <location filename="../../opensessioncontroller.py" line="458"/>
+        <location filename="../../opensessioncontroller.py" line="448"/>
         <source>Name</source>
         <translation>Name</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="459"/>
+        <location filename="../../opensessioncontroller.py" line="449"/>
         <source>Description</source>
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="460"/>
+        <location filename="../../opensessioncontroller.py" line="450"/>
         <source>Path</source>
         <translation>Pfad</translation>
     </message>
@@ -97,13 +97,13 @@
         <source>Double click to add the client nsm-data to write here.
 Use it for notes, TODO, references etcâ¦</source>
         <translation>Um hier zu schreiben doppelklicken Sie auf dieses Feld (startet nsm-data)
-Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
+Für Notizen, TODO, Referenzen, Quellen etc.</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../../designer/mainwindow.py" line="308"/>
+        <location filename="../../designer/mainwindow.py" line="311"/>
         <source>Agordejo</source>
         <translation>Agordejo</translation>
     </message>
@@ -113,17 +113,17 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
         <translation type="obsolete">Neue Session starten</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="352"/>
+        <location filename="../../designer/mainwindow.py" line="354"/>
         <source>Save</source>
         <translation>Speichern</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="356"/>
+        <location filename="../../designer/mainwindow.py" line="358"/>
         <source>Save and Close</source>
         <translation>Speichern und Schließen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="324"/>
+        <location filename="../../designer/mainwindow.py" line="326"/>
         <source>Session Notes</source>
         <translation>Session Notizen</translation>
     </message>
@@ -133,152 +133,152 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
         <translation type="obsolete">Schnelle Ansicht</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="314"/>
+        <location filename="../../designer/mainwindow.py" line="317"/>
         <source>New</source>
         <translation>Neu</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="316"/>
+        <location filename="../../designer/mainwindow.py" line="319"/>
         <source>Load Selected</source>
         <translation>Lade Ausgewählte</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="321"/>
+        <location filename="../../designer/mainwindow.py" line="323"/>
         <source>Tree View</source>
         <translation>Baumansicht</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="322"/>
+        <location filename="../../designer/mainwindow.py" line="324"/>
         <source>Double-click to load program</source>
         <translation>Doppelklick um Programm zu starten</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="323"/>
+        <location filename="../../designer/mainwindow.py" line="325"/>
         <source>In current session</source>
         <translation>Momentan in der Session</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="325"/>
+        <location filename="../../designer/mainwindow.py" line="327"/>
         <source>Full View</source>
         <translation>Volle Ansicht</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="328"/>
+        <location filename="../../designer/mainwindow.py" line="330"/>
         <source>JACK</source>
         <translation>JACK</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="329"/>
+        <location filename="../../designer/mainwindow.py" line="331"/>
         <source>version and running</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="330"/>
+        <location filename="../../designer/mainwindow.py" line="332"/>
         <source>NSM Server Mode</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="331"/>
+        <location filename="../../designer/mainwindow.py" line="333"/>
         <source>Self-started, connected to, environment var</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="332"/>
+        <location filename="../../designer/mainwindow.py" line="334"/>
         <source>NSM Url</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="333"/>
+        <location filename="../../designer/mainwindow.py" line="335"/>
         <source>osc.upd ip port</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="334"/>
+        <location filename="../../designer/mainwindow.py" line="336"/>
         <source>Session Root</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="335"/>
+        <location filename="../../designer/mainwindow.py" line="337"/>
         <source>/home/usr/NSM Sessions</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="336"/>
+        <location filename="../../designer/mainwindow.py" line="338"/>
         <source>Program Database</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="337"/>
+        <location filename="../../designer/mainwindow.py" line="339"/>
         <source>Last Updated</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="339"/>
+        <location filename="../../designer/mainwindow.py" line="341"/>
         <source>Information</source>
         <translation>Information</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="340"/>
+        <location filename="../../designer/mainwindow.py" line="342"/>
         <source>Processing</source>
         <translation>Arbeitet</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="342"/>
+        <location filename="../../designer/mainwindow.py" line="344"/>
         <source>Control</source>
         <translation>Steuerung</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="343"/>
+        <location filename="../../designer/mainwindow.py" line="345"/>
         <source>SessionName</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="344"/>
+        <location filename="../../designer/mainwindow.py" line="346"/>
         <source>ClientNameId</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="345"/>
+        <location filename="../../designer/mainwindow.py" line="347"/>
         <source>Quit</source>
         <translation>Beenden</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="346"/>
+        <location filename="../../designer/mainwindow.py" line="348"/>
         <source>Ctrl+Shift+Q</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="347"/>
+        <location filename="../../designer/mainwindow.py" line="349"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="376"/>
+        <location filename="../../designer/mainwindow.py" line="378"/>
         <source>Manual</source>
         <translation>Handbuch</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="348"/>
+        <location filename="../../designer/mainwindow.py" line="350"/>
         <source>Hide in System Tray</source>
         <translation>Minimieren zum Tray</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="349"/>
+        <location filename="../../designer/mainwindow.py" line="351"/>
         <source>Ctrl+Q</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="350"/>
+        <location filename="../../designer/mainwindow.py" line="352"/>
         <source>Add Client (Prompt)</source>
         <translation>Programm hinzufügen (Prompt)</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="351"/>
+        <location filename="../../designer/mainwindow.py" line="353"/>
         <source>A</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="353"/>
+        <location filename="../../designer/mainwindow.py" line="355"/>
         <source>Ctrl+S</source>
         <translation></translation>
     </message>
@@ -288,12 +288,12 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
         <translation type="obsolete">Speichern unter</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="355"/>
+        <location filename="../../designer/mainwindow.py" line="357"/>
         <source>Ctrl+Shift+S</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="357"/>
+        <location filename="../../designer/mainwindow.py" line="359"/>
         <source>Ctrl+W</source>
         <translation></translation>
     </message>
@@ -303,165 +303,175 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
         <translation type="obsolete">Abbrechen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="359"/>
+        <location filename="../../designer/mainwindow.py" line="361"/>
         <source>Ctrl+Shift+W</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="360"/>
+        <location filename="../../designer/mainwindow.py" line="362"/>
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="361"/>
+        <location filename="../../designer/mainwindow.py" line="363"/>
         <source>Alt+O</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="362"/>
+        <location filename="../../designer/mainwindow.py" line="364"/>
         <source>Resume</source>
         <translation>Fortführen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="363"/>
+        <location filename="../../designer/mainwindow.py" line="365"/>
         <source>Alt+R</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="364"/>
+        <location filename="../../designer/mainwindow.py" line="366"/>
         <source>Save separately</source>
         <translation>Seperat speichern</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="365"/>
+        <location filename="../../designer/mainwindow.py" line="367"/>
         <source>Alt+S</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="366"/>
+        <location filename="../../designer/mainwindow.py" line="368"/>
         <source>Remove</source>
         <translation>Entfernen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="367"/>
+        <location filename="../../designer/mainwindow.py" line="369"/>
         <source>Alt+X</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="368"/>
+        <location filename="../../designer/mainwindow.py" line="370"/>
         <source>Toggle Visible</source>
         <translation>Sichtbarkeit umschalten</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="369"/>
+        <location filename="../../designer/mainwindow.py" line="371"/>
         <source>Alt+T</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="370"/>
+        <location filename="../../designer/mainwindow.py" line="372"/>
         <source>Show All Clients</source>
         <translation>Zeige alle Clients</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="371"/>
+        <location filename="../../designer/mainwindow.py" line="373"/>
         <source>Hide All Clients</source>
         <translation>Verstecke alle Clients</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="372"/>
+        <location filename="../../designer/mainwindow.py" line="374"/>
         <source>Rebuild Program Database</source>
         <translation>Programmdatenbank generieren</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="373"/>
+        <location filename="../../designer/mainwindow.py" line="375"/>
         <source>Rename</source>
         <translation>Umbenennen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="374"/>
+        <location filename="../../designer/mainwindow.py" line="376"/>
         <source>F2</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="375"/>
+        <location filename="../../designer/mainwindow.py" line="377"/>
         <source>Settings</source>
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="354"/>
+        <location filename="../../designer/mainwindow.py" line="356"/>
         <source>Save and Clone under different name</source>
         <translation>Speichern und mit anderem Namen neu öffnen</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="358"/>
+        <location filename="../../designer/mainwindow.py" line="360"/>
         <source>Close without Save (&quot;Abort&quot;)</source>
-        <translation>Schließen ohne zu Speichern (&quot;Abbrechen&quot;)</translation>
+        <translation>Schließen ohne zu Speichern (&amp;quot;Abbrechen&amp;quot;)</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="309"/>
+        <location filename="../../designer/mainwindow.py" line="312"/>
         <source>Global Playback Controls</source>
         <translation>Globaler Zugriff aufs Playback</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="310"/>
+        <location filename="../../designer/mainwindow.py" line="313"/>
         <source>PlayPause</source>
         <translation>PlayPause</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="311"/>
+        <location filename="../../designer/mainwindow.py" line="314"/>
         <source>Rewind</source>
         <translation>Rewind</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="312"/>
+        <location filename="../../designer/mainwindow.py" line="315"/>
         <source> time-placeholder</source>
         <translation> time-placeholder</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="313"/>
+        <location filename="../../designer/mainwindow.py" line="316"/>
         <source> min</source>
         <translation> min</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="315"/>
+        <location filename="../../designer/mainwindow.py" line="318"/>
         <source>Quick New</source>
         <translation>Schnellstart Neu</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="317"/>
+        <location filename="../../designer/mainwindow.py" line="320"/>
         <source>Rename Selected</source>
         <translation>Namen ändern</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="318"/>
+        <location filename="../../designer/mainwindow.py" line="321"/>
         <source>Copy Selected</source>
         <translation>Kopieren</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="319"/>
+        <location filename="../../designer/mainwindow.py" line="322"/>
         <source>Delete Selected</source>
         <translation>Löschen</translation>
     </message>
     <message>
         <location filename="../../designer/mainwindow.py" line="320"/>
         <source>Remove Lock</source>
-        <translation>Lock aufheben</translation>
+        <translation type="obsolete">Lock aufheben</translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="341"/>
+        <location filename="../../designer/mainwindow.py" line="343"/>
         <source>I understand that I will need to resolve this problem on my own!</source>
         <translation>Ich verstehe, dass ich dieses Problem selbst lösen muss!</translation>
     </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="379"/>
+        <source>News and Changelog</source>
+        <translation>News und Changelog</translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="380"/>
+        <source>Split Session View the other way</source>
+        <translation>Sessionfenster anders aufteilen</translation>
+    </message>
 </context>
 <context>
     <name>NOOPEngineStrings</name>
     <message>
-        <location filename="../../mainwindow.py" line="133"/>
+        <location filename="../../mainwindow.py" line="134"/>
         <source>ERROR! Copied session data is different from source session. Please check you data!</source>
         <translation>ERROR! Kopierte Daten der Session unterscheiden sich von der Ursprünlinglichen! Bitte überprüfen Sie die Integrität der kopierten Daten!</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="134"/>
+        <location filename="../../mainwindow.py" line="135"/>
         <source>Veryfying file-integrity. This may take a while...</source>
         <translation>Überprüfe Integrität der Dateien. Bitte haben Sie etwas Geduld...</translation>
     </message>
@@ -494,12 +504,12 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
 <context>
     <name>OpenSession</name>
     <message>
-        <location filename="../../opensessioncontroller.py" line="97"/>
+        <location filename="../../opensessioncontroller.py" line="98"/>
         <source>not saved</source>
         <translation>ungespeichert</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="99"/>
+        <location filename="../../opensessioncontroller.py" line="100"/>
         <source>clean</source>
         <translation>clean</translation>
     </message>
@@ -509,32 +519,32 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
         <translation type="obsolete">(Befehl nicht gefunden)</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="159"/>
+        <location filename="../../opensessioncontroller.py" line="163"/>
         <source>Name</source>
         <translation>Name</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="160"/>
+        <location filename="../../opensessioncontroller.py" line="164"/>
         <source>Label</source>
         <translation>Label</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="161"/>
+        <location filename="../../opensessioncontroller.py" line="165"/>
         <source>Status</source>
         <translation>Status</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="162"/>
+        <location filename="../../opensessioncontroller.py" line="166"/>
         <source>Visible</source>
         <translation>Sichtbarkeit</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="163"/>
+        <location filename="../../opensessioncontroller.py" line="167"/>
         <source>Changes</source>
         <translation>Änderungen</translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="164"/>
+        <location filename="../../opensessioncontroller.py" line="168"/>
         <source>ID</source>
         <translation>ID</translation>
     </message>
@@ -605,92 +615,105 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
     <message>
         <location filename="../../addclientprompt.py" line="68"/>
         <source>Command not accepted!&lt;br&gt;Parameters, --switches and relative paths are not allowed.&lt;br&gt;Use nsm-proxy or write a starter-script instead.</source>
-        <translation type="obsolete">Befehl nicht akzeptiert!&lt;br&gt;Parameter, --schalter und relative Pfade sind nicht erlaubt.&lt;br&gt;Benutzen Sie stattdessen ein Programm wie nsm-proxy oder schreiben sie selbst ein Starterscript.</translation>
+        <translation type="obsolete">Befehl nicht akzeptiert!&amp;lt;br&amp;gt;Parameter, --schalter und relative Pfade sind nicht erlaubt.&amp;lt;br&amp;gt;Benutzen Sie stattdessen ein Programm wie nsm-proxy oder schreiben sie selbst ein Starterscript.</translation>
     </message>
     <message>
         <location filename="../../addclientprompt.py" line="70"/>
         <source>Command not found or not accepted!&lt;br&gt;Parameters, --switches and relative paths are not allowed.&lt;br&gt;Use nsm-proxy or write a starter-script instead.</source>
-        <translation>Befehl nicht gefunden oder nicht akzeptiert!&lt;br&gt;Parameter, --schalter und relative Pfade sind nicht erlaubt.&lt;br&gt;Benutzen Sie stattdessen ein Programm wie nsm-proxy oder schreiben sie selbst ein Starterscript.</translation>
+        <translation>Befehl nicht gefunden oder nicht akzeptiert!&amp;lt;br&amp;gt;Parameter, --schalter und relative Pfade sind nicht erlaubt.&amp;lt;br&amp;gt;Benutzen Sie stattdessen ein Programm wie nsm-proxy oder schreiben sie selbst ein Starterscript.</translation>
     </message>
 </context>
 <context>
     <name>SessionTree</name>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="149"/>
+        <location filename="../../sessiontreecontroller.py" line="145"/>
         <source>Name</source>
         <translation>Name</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="150"/>
+        <location filename="../../sessiontreecontroller.py" line="146"/>
         <source>Last Save</source>
         <translation>Letzte Speicherung</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="151"/>
+        <location filename="../../sessiontreecontroller.py" line="147"/>
         <source>Clients</source>
         <translation>Clients</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="152"/>
+        <location filename="../../sessiontreecontroller.py" line="148"/>
         <source>Size</source>
         <translation>Größe</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="153"/>
+        <location filename="../../sessiontreecontroller.py" line="149"/>
         <source>Symlinks</source>
         <translation>Symlinks</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="154"/>
+        <location filename="../../sessiontreecontroller.py" line="150"/>
         <source>Path</source>
         <translation>Pfad</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="257"/>
+        <location filename="../../sessiontreecontroller.py" line="254"/>
         <source>About to delete Session {}</source>
         <translation>Session {} soll gelöscht werden</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="256"/>
+        <location filename="../../sessiontreecontroller.py" line="253"/>
         <source>All files in the project directory will be irreversibly deleted.</source>
         <translation>Alle Dateien aus diesem Projektverzeichnis werden unwiederbringlich gelöscht.</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="265"/>
+        <location filename="../../sessiontreecontroller.py" line="262"/>
         <source>Keep Session</source>
         <translation>Session behalten</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="266"/>
+        <location filename="../../sessiontreecontroller.py" line="263"/>
         <source>Delete!</source>
         <translation>Löschen!</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="282"/>
+        <location filename="../../sessiontreecontroller.py" line="279"/>
         <source>Copy Session</source>
         <translation>Session kopieren</translation>
     </message>
     <message>
         <location filename="../../sessiontreecontroller.py" line="285"/>
         <source>Force Lock Removal</source>
-        <translation>Lockdatei Aufhebung erzwingen</translation>
+        <translation type="obsolete">Lockdatei Aufhebung erzwingen</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="287"/>
+        <location filename="../../sessiontreecontroller.py" line="282"/>
         <source>Rename Session</source>
         <translation>Session umbennen</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="289"/>
+        <location filename="../../sessiontreecontroller.py" line="284"/>
         <source>Delete Session</source>
         <translation>Session löschen</translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="344"/>
+        <location filename="../../sessiontreecontroller.py" line="342"/>
         <source>Copying {} to {}</source>
         <translation>Kopiere {} nach {}</translation>
     </message>
 </context>
+<context>
+    <name>TemplateChangelog</name>
+    <message>
+        <location filename="../../changelog.py" line="49"/>
+        <source>Changelog</source>
+        <translation>Changelog</translation>
+    </message>
+    <message>
+        <location filename="../../changelog.py" line="50"/>
+        <source>The Changelog is only available in English.</source>
+        <translation>Den Changelog gibt es nur auf Englisch.</translation>
+    </message>
+</context>
 <context>
     <name>TemplateUserManual</name>
     <message>
@@ -758,12 +781,12 @@ Für Notizen, TODO, Referenzen, Quellen etcâ¦</translation>
 <context>
     <name>mainWindow</name>
     <message>
-        <location filename="../../mainwindow.py" line="213"/>
+        <location filename="../../mainwindow.py" line="203"/>
         <source>Agordejo ready</source>
         <translation>Agordejo ist bereit</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="248"/>
+        <location filename="../../mainwindow.py" line="238"/>
         <source>Another GUI tried to launch.</source>
         <translation>Es wurde versucht eine weitere GUI zu starten.</translation>
     </message>
@@ -775,7 +798,7 @@ Thank you for your patience.</source>
 Vielen Dank für ihre Geduld.</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="291"/>
+        <location filename="../../mainwindow.py" line="277"/>
         <source>Updating Program Database.
 Thank you for your patience.
 If progress freezes please kill and restart the whole program.</source>
