@@ -1,34 +1,35 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="it" sourcelanguage="">
+<!DOCTYPE TS>
+<TS version="2.1" language="it">
 <context>
     <name>AskBeforeQuit</name>
     <message>
-        <location filename="../../mainwindow.py" line="331"/>
+        <location filename="../../mainwindow.py" line="329"/>
         <source>About to quit but session {} still open</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="332"/>
+        <location filename="../../mainwindow.py" line="330"/>
         <source>Do you want to save?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="333"/>
+        <location filename="../../mainwindow.py" line="331"/>
         <source>About to quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="342"/>
+        <location filename="../../mainwindow.py" line="340"/>
         <source>Don&apos;t Quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="343"/>
+        <location filename="../../mainwindow.py" line="341"/>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="344"/>
+        <location filename="../../mainwindow.py" line="342"/>
         <source>Discard Changes</source>
         <translation type="unfinished"></translation>
     </message>
@@ -74,17 +75,17 @@
 <context>
     <name>Launcher</name>
     <message>
-        <location filename="../../opensessioncontroller.py" line="458"/>
+        <location filename="../../opensessioncontroller.py" line="448"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="459"/>
+        <location filename="../../opensessioncontroller.py" line="449"/>
         <source>Description</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="460"/>
+        <location filename="../../opensessioncontroller.py" line="450"/>
         <source>Path</source>
         <translation type="unfinished"></translation>
     </message>
@@ -101,345 +102,350 @@ Use it for notes, TODO, references etc&#xe2;&#x80;&#xa6;</source>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../../designer/mainwindow.py" line="308"/>
+        <location filename="../../designer/mainwindow.py" line="311"/>
         <source>Agordejo</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="352"/>
+        <location filename="../../designer/mainwindow.py" line="354"/>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="356"/>
+        <location filename="../../designer/mainwindow.py" line="358"/>
         <source>Save and Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="324"/>
+        <location filename="../../designer/mainwindow.py" line="326"/>
         <source>Session Notes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="314"/>
+        <location filename="../../designer/mainwindow.py" line="317"/>
         <source>New</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="316"/>
+        <location filename="../../designer/mainwindow.py" line="319"/>
         <source>Load Selected</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="321"/>
+        <location filename="../../designer/mainwindow.py" line="323"/>
         <source>Tree View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="322"/>
+        <location filename="../../designer/mainwindow.py" line="324"/>
         <source>Double-click to load program</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="323"/>
+        <location filename="../../designer/mainwindow.py" line="325"/>
         <source>In current session</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="325"/>
+        <location filename="../../designer/mainwindow.py" line="327"/>
         <source>Full View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="328"/>
+        <location filename="../../designer/mainwindow.py" line="330"/>
         <source>JACK</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="329"/>
+        <location filename="../../designer/mainwindow.py" line="331"/>
         <source>version and running</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="330"/>
+        <location filename="../../designer/mainwindow.py" line="332"/>
         <source>NSM Server Mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="331"/>
+        <location filename="../../designer/mainwindow.py" line="333"/>
         <source>Self-started, connected to, environment var</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="332"/>
+        <location filename="../../designer/mainwindow.py" line="334"/>
         <source>NSM Url</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="333"/>
+        <location filename="../../designer/mainwindow.py" line="335"/>
         <source>osc.upd ip port</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="334"/>
+        <location filename="../../designer/mainwindow.py" line="336"/>
         <source>Session Root</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="335"/>
+        <location filename="../../designer/mainwindow.py" line="337"/>
         <source>/home/usr/NSM Sessions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="336"/>
+        <location filename="../../designer/mainwindow.py" line="338"/>
         <source>Program Database</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="337"/>
+        <location filename="../../designer/mainwindow.py" line="339"/>
         <source>Last Updated</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="339"/>
+        <location filename="../../designer/mainwindow.py" line="341"/>
         <source>Information</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="340"/>
+        <location filename="../../designer/mainwindow.py" line="342"/>
         <source>Processing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="342"/>
+        <location filename="../../designer/mainwindow.py" line="344"/>
         <source>Control</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="343"/>
+        <location filename="../../designer/mainwindow.py" line="345"/>
         <source>SessionName</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="344"/>
+        <location filename="../../designer/mainwindow.py" line="346"/>
         <source>ClientNameId</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="345"/>
+        <location filename="../../designer/mainwindow.py" line="347"/>
         <source>Quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="346"/>
+        <location filename="../../designer/mainwindow.py" line="348"/>
         <source>Ctrl+Shift+Q</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="347"/>
+        <location filename="../../designer/mainwindow.py" line="349"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="348"/>
+        <location filename="../../designer/mainwindow.py" line="350"/>
         <source>Hide in System Tray</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="349"/>
+        <location filename="../../designer/mainwindow.py" line="351"/>
         <source>Ctrl+Q</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="350"/>
+        <location filename="../../designer/mainwindow.py" line="352"/>
         <source>Add Client (Prompt)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="351"/>
+        <location filename="../../designer/mainwindow.py" line="353"/>
         <source>A</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="353"/>
+        <location filename="../../designer/mainwindow.py" line="355"/>
         <source>Ctrl+S</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="354"/>
+        <location filename="../../designer/mainwindow.py" line="356"/>
         <source>Save and Clone under different name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="355"/>
+        <location filename="../../designer/mainwindow.py" line="357"/>
         <source>Ctrl+Shift+S</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="357"/>
+        <location filename="../../designer/mainwindow.py" line="359"/>
         <source>Ctrl+W</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="358"/>
+        <location filename="../../designer/mainwindow.py" line="360"/>
         <source>Close without Save (&quot;Abort&quot;)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="359"/>
+        <location filename="../../designer/mainwindow.py" line="361"/>
         <source>Ctrl+Shift+W</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="360"/>
+        <location filename="../../designer/mainwindow.py" line="362"/>
         <source>Stop</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="361"/>
+        <location filename="../../designer/mainwindow.py" line="363"/>
         <source>Alt+O</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="362"/>
+        <location filename="../../designer/mainwindow.py" line="364"/>
         <source>Resume</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="363"/>
+        <location filename="../../designer/mainwindow.py" line="365"/>
         <source>Alt+R</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="364"/>
+        <location filename="../../designer/mainwindow.py" line="366"/>
         <source>Save separately</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="365"/>
+        <location filename="../../designer/mainwindow.py" line="367"/>
         <source>Alt+S</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="366"/>
+        <location filename="../../designer/mainwindow.py" line="368"/>
         <source>Remove</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="367"/>
+        <location filename="../../designer/mainwindow.py" line="369"/>
         <source>Alt+X</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="368"/>
+        <location filename="../../designer/mainwindow.py" line="370"/>
         <source>Toggle Visible</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="369"/>
+        <location filename="../../designer/mainwindow.py" line="371"/>
         <source>Alt+T</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="370"/>
+        <location filename="../../designer/mainwindow.py" line="372"/>
         <source>Show All Clients</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="371"/>
+        <location filename="../../designer/mainwindow.py" line="373"/>
         <source>Hide All Clients</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="372"/>
+        <location filename="../../designer/mainwindow.py" line="374"/>
         <source>Rebuild Program Database</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="373"/>
+        <location filename="../../designer/mainwindow.py" line="375"/>
         <source>Rename</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="374"/>
+        <location filename="../../designer/mainwindow.py" line="376"/>
         <source>F2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="375"/>
+        <location filename="../../designer/mainwindow.py" line="377"/>
         <source>Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="376"/>
+        <location filename="../../designer/mainwindow.py" line="378"/>
         <source>Manual</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="309"/>
+        <location filename="../../designer/mainwindow.py" line="312"/>
         <source>Global Playback Controls</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="310"/>
+        <location filename="../../designer/mainwindow.py" line="313"/>
         <source>PlayPause</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="311"/>
+        <location filename="../../designer/mainwindow.py" line="314"/>
         <source>Rewind</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="312"/>
+        <location filename="../../designer/mainwindow.py" line="315"/>
         <source> time-placeholder</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="313"/>
+        <location filename="../../designer/mainwindow.py" line="316"/>
         <source> min</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="315"/>
+        <location filename="../../designer/mainwindow.py" line="318"/>
         <source>Quick New</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="317"/>
+        <location filename="../../designer/mainwindow.py" line="320"/>
         <source>Rename Selected</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="318"/>
+        <location filename="../../designer/mainwindow.py" line="321"/>
         <source>Copy Selected</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="319"/>
+        <location filename="../../designer/mainwindow.py" line="322"/>
         <source>Delete Selected</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="320"/>
-        <source>Remove Lock</source>
+        <location filename="../../designer/mainwindow.py" line="343"/>
+        <source>I understand that I will need to resolve this problem on my own!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../designer/mainwindow.py" line="341"/>
-        <source>I understand that I will need to resolve this problem on my own!</source>
+        <location filename="../../designer/mainwindow.py" line="379"/>
+        <source>News and Changelog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../designer/mainwindow.py" line="380"/>
+        <source>Split Session View the other way</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>NOOPEngineStrings</name>
     <message>
-        <location filename="../../mainwindow.py" line="133"/>
+        <location filename="../../mainwindow.py" line="134"/>
         <source>ERROR! Copied session data is different from source session. Please check you data!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="134"/>
+        <location filename="../../mainwindow.py" line="135"/>
         <source>Veryfying file-integrity. This may take a while...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -472,42 +478,42 @@ Use it for notes, TODO, references etc&#xe2;&#x80;&#xa6;</source>
 <context>
     <name>OpenSession</name>
     <message>
-        <location filename="../../opensessioncontroller.py" line="97"/>
+        <location filename="../../opensessioncontroller.py" line="98"/>
         <source>not saved</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="99"/>
+        <location filename="../../opensessioncontroller.py" line="100"/>
         <source>clean</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="159"/>
+        <location filename="../../opensessioncontroller.py" line="163"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="160"/>
+        <location filename="../../opensessioncontroller.py" line="164"/>
         <source>Label</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="161"/>
+        <location filename="../../opensessioncontroller.py" line="165"/>
         <source>Status</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="162"/>
+        <location filename="../../opensessioncontroller.py" line="166"/>
         <source>Visible</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="163"/>
+        <location filename="../../opensessioncontroller.py" line="167"/>
         <source>Changes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../opensessioncontroller.py" line="164"/>
+        <location filename="../../opensessioncontroller.py" line="168"/>
         <source>ID</source>
         <translation type="unfinished"></translation>
     </message>
@@ -579,81 +585,89 @@ Use it for notes, TODO, references etc&#xe2;&#x80;&#xa6;</source>
 <context>
     <name>SessionTree</name>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="149"/>
+        <location filename="../../sessiontreecontroller.py" line="145"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="150"/>
+        <location filename="../../sessiontreecontroller.py" line="146"/>
         <source>Last Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="151"/>
+        <location filename="../../sessiontreecontroller.py" line="147"/>
         <source>Clients</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="152"/>
+        <location filename="../../sessiontreecontroller.py" line="148"/>
         <source>Size</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="153"/>
+        <location filename="../../sessiontreecontroller.py" line="149"/>
         <source>Symlinks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="154"/>
+        <location filename="../../sessiontreecontroller.py" line="150"/>
         <source>Path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="257"/>
+        <location filename="../../sessiontreecontroller.py" line="254"/>
         <source>About to delete Session {}</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="256"/>
+        <location filename="../../sessiontreecontroller.py" line="253"/>
         <source>All files in the project directory will be irreversibly deleted.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="265"/>
+        <location filename="../../sessiontreecontroller.py" line="262"/>
         <source>Keep Session</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="266"/>
+        <location filename="../../sessiontreecontroller.py" line="263"/>
         <source>Delete!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="282"/>
+        <location filename="../../sessiontreecontroller.py" line="279"/>
         <source>Copy Session</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="285"/>
-        <source>Force Lock Removal</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../sessiontreecontroller.py" line="287"/>
+        <location filename="../../sessiontreecontroller.py" line="282"/>
         <source>Rename Session</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="289"/>
+        <location filename="../../sessiontreecontroller.py" line="284"/>
         <source>Delete Session</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../sessiontreecontroller.py" line="344"/>
+        <location filename="../../sessiontreecontroller.py" line="342"/>
         <source>Copying {} to {}</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>TemplateChangelog</name>
+    <message>
+        <location filename="../../changelog.py" line="49"/>
+        <source>Changelog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../changelog.py" line="50"/>
+        <source>The Changelog is only available in English.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>TemplateUserManual</name>
     <message>
@@ -721,17 +735,17 @@ Use it for notes, TODO, references etc&#xe2;&#x80;&#xa6;</source>
 <context>
     <name>mainWindow</name>
     <message>
-        <location filename="../../mainwindow.py" line="213"/>
+        <location filename="../../mainwindow.py" line="203"/>
         <source>Agordejo ready</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="248"/>
+        <location filename="../../mainwindow.py" line="238"/>
         <source>Another GUI tried to launch.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainwindow.py" line="291"/>
+        <location filename="../../mainwindow.py" line="277"/>
         <source>Updating Program Database.
 Thank you for your patience.
 If progress freezes please kill and restart the whole program.</source>
