@@ -98,16 +98,12 @@ class SessionItem(QtWidgets.QTreeWidgetItem):
 
     def setLocked(self, state:bool):
         """Number of clients, symlinks and size change frequently while a session is open/locked.
-        We deactivate the display of these values while locked"""
-        return
-        if not state == self.isDisabled():
-            self.setDisabled(state)
-            if state:
-                self.setText(2, "") #number of clients
-                self.setText(3, "") #Symlinks
-                self.setText(4, "") #Size
-            else:
-                self.updateData()
+        We deactivate the display of these values while locked
+
+        This is also used for nsmd lockfiles and locked sessions, aka session open by another nsmd.
+        """
+        self.updateData()
+        self.setDisabled(state)
 
     def updateTimestamp(self, timestamp:str):
         #Column 1 "Last Save"
@@ -184,7 +180,6 @@ class SessionTreeController(object):
         self.mainWindow.ui.button_copy_selected_session.clicked.connect(lambda: self._askForCopyAndCopy(self.treeWidget.currentItem().sessionDict["nsmSessionName"]))
         self.mainWindow.ui.button_rename_selected_session.clicked.connect(lambda: self._askForNameAndRenameSession(self.treeWidget.currentItem().sessionDict["nsmSessionName"]))
         self.mainWindow.ui.button_delete_selected_session.clicked.connect(lambda: self.deleteSessionItem(self.treeWidget.currentItem()))
-        self.mainWindow.ui.button_remove_lock_selected_session.clicked.connect(lambda: api.sessionForceLiftLock(self.treeWidget.currentItem().sessionDict["nsmSessionName"]))
 
         logger.info("Full View Session Chooser ready")
 
@@ -283,9 +278,7 @@ class SessionTreeController(object):
         listOfLabelsAndFunctions = [
             (QtCore.QCoreApplication.translate("SessionTree", "Copy Session"), lambda: self._askForCopyAndCopy(item.sessionDict["nsmSessionName"]))
             ]
-        if item.isDisabled():
-            listOfLabelsAndFunctions.append((QtCore.QCoreApplication.translate("SessionTree", "Force Lock Removal"), lambda: api.sessionForceLiftLock(item.sessionDict["nsmSessionName"])))
-        else:
+        if not item.isDisabled() and not item.sessionDict["locked"]:
             listOfLabelsAndFunctions.append((QtCore.QCoreApplication.translate("SessionTree", "Rename Session"), lambda: self._askForNameAndRenameSession(item.sessionDict["nsmSessionName"])))
             #Delete should be the bottom item.
             listOfLabelsAndFunctions.append((QtCore.QCoreApplication.translate("SessionTree", "Delete Session"), lambda: self.deleteSessionItem(item)))
@@ -313,7 +306,6 @@ class SessionTreeController(object):
     def _reactSelectionChanged(self, item, previous):
         """User clicks on an entry in the session chooser, or in the empty space.
         in any case, the selection changes and we can decide if we activate/deactivate certain buttons"""
-
         if not item or not type(item) is SessionItem or item.sessionDict["locked"] == True:
             sessionSelectedState = False
         else:
@@ -323,7 +315,6 @@ class SessionTreeController(object):
         self.mainWindow.ui.button_copy_selected_session.setEnabled(sessionSelectedState)
         self.mainWindow.ui.button_rename_selected_session.setEnabled(sessionSelectedState)
         self.mainWindow.ui.button_delete_selected_session.setEnabled(sessionSelectedState)
-        self.mainWindow.ui.button_remove_lock_selected_session.setEnabled(sessionSelectedState and item.sessionDict["locked"] == True)
 
     def _reactSignal_itemDoubleClicked(self, item:QtWidgets.QTreeWidgetItem, column:int):
         if not item.isDisabled() and type(item) is SessionItem:
@@ -385,4 +376,3 @@ class SessionTreeController(object):
         if self._cachedSessionDicts: #not startup
             self._reactCallback_sessionsChanged(self._cachedSessionDicts)
             self.treeWidget.sortItems(self.sortByColumnValue, self.sortDescendingValue)
-
